assert_full_coverage

Function assert_full_coverage 

pub fn assert_full_coverage(
    results: impl IntoIterator<Item = Vec<([u8; 4], &'static str)>>,
)
Available on crate features test-utils only.
Asserts that multiple selector coverage checks all pass (no unsupported selectors).

Takes an iterator of unsupported selector results and panics if any are found.